@@ -1,6 +1,6 @@
-from procraft.prompt_helper import Intel,IntellectType
-from procraft.log import Log
-from procraft.utils import extract_
+from pro_craft.prompt_helper import Intel,IntellectType
+from pro_craft.log import Log
+from pro_craft.utils import extract_
 from typing import List, Dict, Any
 from llmada.core import BianXieAdapter
 import re
